==> fred-hermes-1.0.0.tar.gz: fred-hermes-1.0.0/hermes/letter.py <==
"""High level API for letters."""
from dataclasses import asdict, dataclass
from typing import Any, Dict, Optional, Type
from uuid import UUID

from typist import SecretaryClient

from .message import Message, MessageEnvelope


@dataclass
class Address:
    """Letter recipient address."""

    name: Optional[str] = None
    organization: Optional[str] = None
    street: Optional[str] = None
    city: Optional[str] = None
    state_or_province: Optional[str] = None
    postal_code: Optional[str] = None
    country_code: Optional[str] = None


class Letter(Message):
    """Provide a structure for letter message."""

    rendered_fields = ()

    def __init__(
        self,
        recipient: Address,
        file: UUID,
        *,
        type: str = None,
        secretary_client: SecretaryClient = None
    ):
        """Create letter message."""
        super().__init__(type=type, secretary_client=secretary_client)
        self.recipient = recipient
        self.file = file

    @classmethod
    def from_dict(cls: Type['Letter'], data: Dict[str, Any], *, secretary_client: SecretaryClient = None) -> 'Letter':
        """Create letter instance from a dictionary.

        Raises:
            ValueError: If required keys for message creation are missing
        """
        if 'recipient' in data:
            data['recipient'] = Address(**data['recipient'])
        return super().from_dict(data, secretary_client=secretary_client)

    def to_dict(self) -> Dict[str, Any]:
        """Return dictionary with letter info.

        This method is useful for letter serialization.
        """
        info = super().to_dict()
        info.update({
            'recipient': asdict(self.recipient),
            'file': self.file,
        })
        return info


class LetterEnvelope(MessageEnvelope[Letter]):
    """Provide a structure for letter envelope."""

    message_cls = Letter

==> fred-hermes-1.0.1.tar.gz: fred-hermes-1.0.1/hermes/letter.py <==
"""High level API for letters."""
from dataclasses import asdict, dataclass
from typing import Any, Dict, Optional, Type
from uuid import UUID

from typist import SecretaryClient

from .message import Message, MessageEnvelope


@dataclass
class Address:
    """Letter recipient address."""

    name: Optional[str] = None
    organization: Optional[str] = None
    street: Optional[str] = None
    city: Optional[str] = None
    state_or_province: Optional[str] = None
    postal_code: Optional[str] = None
    country_code: Optional[str] = None


class Letter(Message):
    """Provide a structure for letter message."""

    rendered_fields = ()

    def __init__(
        self,
        recipient: Address,
        file: UUID,
        *,
        type: str = None,
        secretary_client: SecretaryClient = None
    ):
        """Create letter message."""
        super().__init__(type=type, secretary_client=secretary_client)
        self.recipient = recipient
        self.file = file

    @classmethod
    def from_dict(cls: Type['Letter'], data: Dict[str, Any], *, secretary_client: SecretaryClient = None) -> 'Letter':
        """Create letter instance from a dictionary.

        Raises:
            ValueError: If required keys for message creation are missing
        """
        data_copy = data.copy()
        if 'recipient' in data:
            data_copy['recipient'] = Address(**data['recipient'])
        return super().from_dict(data_copy, secretary_client=secretary_client)

    def to_dict(self) -> Dict[str, Any]:
        """Return dictionary with letter info.

        This method is useful for letter serialization.
        """
        info = super().to_dict()
        info.update({
            'recipient': asdict(self.recipient),
            'file': self.file,
        })
        return info


class LetterEnvelope(MessageEnvelope[Letter]):
    """Provide a structure for letter envelope."""

    message_cls = Letter
